# AI Capability Review Through Practice

Internal Knowledge Sharing Session

AI Capabilities

- Access AI Agent through Web Application
- Brainstorming & Web Searching
- File System Accessing
- Making PPT & UI/UX Mockup
- Rule Based Works & Programming Tools
- Voice to Text & Live Translation
- Memory for AI

Today's Scenarios

- Ideation Refinement With AI
- Create Reporting PPT
- Create Application UI/UX Mockup
- Ideation to Requirement Delivery

All scenarios demonstrated in an integrated project environment